@@ -1,7 +1,7 @@
 //! ASN.1 `IA5String` support.
 
 use crate::{
-    str_slice::StrSlice, Any, Encodable, Encoder, Error, ErrorKind, Length, Result, Tag, Tagged,
+    asn1::Any, str_slice::StrSlice, Encodable, Encoder, Error, Length, Result, Tag, Tagged,
 };
 use core::{convert::TryFrom, fmt, str};
 
@@ -12,7 +12,7 @@ use core::{convert::TryFrom, fmt, str};
 /// technically known as the International Reference Alphabet or IRA as
 /// specified in the ITU-T's T.50 recommendation).
 ///
-/// For UTF-8, use [`Utf8String`][`crate::Utf8String`].
+/// For UTF-8, use [`Utf8String`][`crate::asn1::Utf8String`].
 ///
 /// [International Alphabet No. 5 (IA5)]: https://en.wikipedia.org/wiki/T.50_%28standard%29
 #[derive(Copy, Clone, Eq, PartialEq, PartialOrd, Ord)]
@@ -31,12 +31,12 @@ impl<'a> Ia5String<'a> {
 
         // Validate all characters are within IA5String's allowed set
         if input.iter().any(|&c| c > 0x7F) {
-            return Err(ErrorKind::Value { tag: Self::TAG }.into());
+            return Err(Self::TAG.value_error());
         }
 
         StrSlice::from_bytes(input)
             .map(|inner| Self { inner })
-            .map_err(|_| ErrorKind::Value { tag: Self::TAG }.into())
+            .map_err(|_| Self::TAG.value_error())
     }
 
     /// Borrow the string as a `str`.
